import { Injectable }              from '@angular/core';
import { BehaviorSubject }         from 'rxjs/BehaviorSubject';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { AppConfigService } from './app.config.service';
import { RewardService } from './reward.service';

// Data model
import { CouponModel, RewardModel } from './data.model';

import { RewardsSummaryService } from './rewards-summary.service';

// Window global declaration
function _window (): any {
    return window;
}

declare var $: any;

@Injectable ()
export class ClipService {
    public constructor ( private _http: HttpClient, private _appConfigService: AppConfigService,  private _rewardService: RewardService, private _rewardSummaryService: RewardsSummaryService ) {}

    public clipCoupon ( coupon: CouponModel, callback ) {
        console.log ( "clipCoupon Service :", coupon );
        if ( _window ().AB.COMMON.authorizeJ4U () ) {
            console.log ( " YES AUTHORIZED " );
            let httpOptions = { headers: new HttpHeaders ( window[ 'AB' ].j4uHttpOptions ) };
            let reqBody = {};
            if(coupon.deleted){
             reqBody = {
                            items: [
                                {
                                    clipType: 'L',
                                    itemId: coupon.offerId,
                                    itemType: coupon.offerPgm,
                                },
                            ],
                        };
            } else {
             reqBody = {
                            items: [
                                {
                                    clipType: 'C',
                                    itemId: coupon.offerId,
                                    itemType: coupon.offerPgm,
                                },
                                {
                                    clipType: 'L',
                                    itemId: coupon.offerId,
                                    itemType: coupon.offerPgm,
                                },
                            ],
                        };
            }


            this._http.post ( window[ 'AB' ][ 'couponClipPath' ], reqBody, httpOptions )
                .subscribe ( ( response ) => {
                    console.log ( 'clip response', response );
                    let allCoupons = JSON.parse ( localStorage.getItem ( 'abCoupons' ) );
                    allCoupons.offers[ coupon.id ].status = 'C';
                    localStorage.setItem ( 'abCoupons', JSON.stringify ( allCoupons ) );
                    callback ();
                }, err => console.error ( 'clip error', err ) );

        }
        else {
            console.log ( " NO AUTHORIZED " );
            _window ().AB.COMMON.showCreateAccontModalJ4U ();
        }
    }

    public clipReward ( reward: RewardModel, callback ) {
        if ( _window ().AB.COMMON.authorizeJ4U () ) {

           if(window['SWY']['ENFORCEMENT'].isTokenActive()) {
               this.doRedeemReward(reward, callback);
           }
           else if (window['SWY']['ENFORCEMENT'].checkAuthorizedCookie()) {
               this._http.get(window['AB']['userInfoPath']).subscribe(data => {
                    window['AB']['userInfo'].updateTokenRefreshProperty();
                    this.doRedeemReward(reward, callback);
               },error => {
                   reward.isConfirmModalButtonDisabled = false;
                    window['AB']['COMMON'].redirectErrorPage();
               });
           }
        }
        else {
            console.log ( " NO AUTHORIZED " );
            reward.isConfirmModalButtonDisabled = false;
            _window ().AB.COMMON.showCreateAccontModalJ4U ();

        }
    }

    public doRedeemReward ( reward: RewardModel, callback ) {
        let httpOptions = { headers: new HttpHeaders ( window[ 'AB' ].j4uHttpOptions ) };
        let rewardUrl = window['AB']['couponClipPath'] + "?storeId=" + window['AB']['userInfo']['j4u']['storeId'];
        const reqBody = {
            items: [
                {
                    clipType: 'C',
                    itemId: reward.groceryRewardId,
                    itemType: reward.offerPgm,

                },
                {
                    clipType: 'L',
                    itemId: reward.groceryRewardId,
                    itemType: reward.offerPgm,

                },
            ],
        };

        this._http.post ( rewardUrl, reqBody, httpOptions )
            .subscribe ( ( response ) => {
                if(response['items']){
                    // Got the response with Items
                    let items = response["items"];
                    // look for the error codes in the response
                    if( items[0]['status'] == 1 ){
                        // Success
                        this._updateLocalStorageRewardsInfo(reward);

                        this._rewardService.updateTimeToRefresh();

                        this._appConfigService.rewardsRefreshSource.next (true);

                        this._updateRewardsAnalytics(reward);

                        // Refresh the page after all is success
                        window.location.href = window.location.href.split('justforu')[0] +'justforu/rewards.html';

                    } else {
                        this._handleErrorMessage(reward, items);
                    }
                } else {
                    this._handleErrorMessage(reward, []);
                }
            }, err => {
                console.error('clip error', err);

                let strError = err.status + ": Rewards Clip failed";
                if(err.error && err.error.items && Array.isArray(err.error.items) && err.error.items.length > 0) {
                    this._handleErrorMessage(reward, err.error.items);
                }else if( err.message && err.status ) {
                    strError += " " + err.message + " " + err.status;
                    this._handleErrorMessage(reward, []);
                }
                window['AB']['DATALAYER'].setError(reward.groceryRewardId.toString(), 'rewards clipping', strError);
                window['AB']['DATALAYER'].updateSatelliteTrack('grocery_rewards_error');
            });
    }

    private _handleErrorMessage(reward: RewardModel, items){
        let errorTitle:string
            , errorMessage:string
            , strSystemError:string;

        if( items && items.length > 0 ){
            strSystemError = "400: Rewards Clip failed - status is 0";
            if(items[0].errorCd && items[0].errorMsg) {
                strSystemError += " " + items[0].errorCd + " " + items[0].errorMsg;
            }

            if(items[0]['errorCd'] && items[0]['errorCd'] === 'EMJOC8024E'){
                // Show Insufficient Balance message.
                errorTitle = 'Oops';
                errorMessage = 'Your reward balance is being updated, please check back in a few minutes.';
            } else {
                // Show Generic Error
                errorTitle = 'Service Problem';
                errorMessage = 'System is currently unavailable, please try again later.';
            }
        } else {
            // Show Generic Error
            strSystemError = "400: Rewards Clip failed - items is not defined. ";

            errorTitle = 'Service Problem';
            errorMessage = 'System is currently unavailable, please try again later.';
        }

        // Hide the Modal in case of error.
        let modalID = "#rewards-redemption-confirmation-modal-" + reward.groceryRewardId;
        $(modalID).modal('hide');

        //Show error message
        window['AB']['COMMON'].popupUserErrorMessage(errorTitle, errorMessage, function(){
            // Refresh the page after user clicks the button.
            window.location.href = window.location.href.split('justforu')[0] +'justforu/rewards.html';
        });

        window['AB']['DATALAYER'].setError(reward.groceryRewardId.toString(), 'rewards clipping', strSystemError);
        window['AB']['DATALAYER'].updateSatelliteTrack('grocery_rewards_error');
    }

    private _updateRewardsAnalytics(reward: RewardModel) {
        window['AB']['DATALAYER'].clipReward(reward);
    }

    // Update the local storage for temporary storing the rewards.
    private _updateLocalStorageRewardsInfo(reward: RewardModel){
        if(this._appConfigService.isLSCompatible()){
            let abRewardsSummaryLS = localStorage.abRewardsSummary;
            if(this._rewardSummaryService.checkSummaryTime(abRewardsSummaryLS)){
                let objRewardsPoints = JSON.parse(abRewardsSummaryLS);
                let rewardsAvailable = objRewardsPoints.rewardsAvailable - reward.rewardsRequired;
                // If the rewardReq is greater then the expRewards
                // replace it with Zero.
                // else (expReward - rewardReq)
                let rewardExpire = (objRewardsPoints.rewardsExpire > reward.rewardsRequired) ?
                    objRewardsPoints.rewardsExpire - reward.rewardsRequired : 0;
                let time = Date.now();
                let abRewardsSummary = { 'rewardsAvailable': rewardsAvailable,'rewardsExpire' :rewardExpire, 'savedTime': time };
                localStorage.abRewardsSummary = JSON.stringify(abRewardsSummary);
            }else{
                let rewardsAvailable = reward.rewardsAvailable - reward.rewardsRequired;
                let rewardExpire = (reward.rewardsExpire > reward.rewardsRequired) ? (reward.rewardsExpire - reward.rewardsRequired) : 0;
                let time = Date.now();
                let abRewardsSummary = { 'rewardsAvailable': rewardsAvailable,'rewardsExpire' :rewardExpire, 'savedTime': time };
                localStorage.abRewardsSummary = JSON.stringify(abRewardsSummary);
            }
        }
    }
}
