"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var BehaviorSubject_1 = require("rxjs/BehaviorSubject");
var CouponFilterService = /** @class */ (function () {
    function CouponFilterService() {
        /* Source Params */
        this.couponCategorySource = new BehaviorSubject_1.BehaviorSubject([]);
        this.currentCouponCategory = this.couponCategorySource.asObservable();
        this.couponEventSource = new BehaviorSubject_1.BehaviorSubject([]);
        this.currentCouponEvent = this.couponEventSource.asObservable();
        this.couponOfferTypeSource = new BehaviorSubject_1.BehaviorSubject([]);
        this.currentCouponOfferType = this.couponOfferTypeSource.asObservable();
        this.couponAisleTypeSource = new BehaviorSubject_1.BehaviorSubject([]);
        this.currentCouponAisleType = this.couponAisleTypeSource.asObservable();
        /* Filter Source Params */
        this.filterCategoryParamSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentFilterCategory = this.filterCategoryParamSource.asObservable();
        this.filterEventParamSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentFilterEvent = this.filterEventParamSource.asObservable();
        this.filterOfferTypeParamSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentFilterOfferType = this.filterOfferTypeParamSource.asObservable();
        this.filterAisleTypeParamSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentFilterAisleType = this.filterAisleTypeParamSource.asObservable();
        this.addFilterSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentFilterAdded = this.addFilterSource.asObservable();
        this.addAllFilters = new BehaviorSubject_1.BehaviorSubject(false);
        this.offerTypeFilterCounter = new BehaviorSubject_1.BehaviorSubject(0);
        this.currentOfferTypeFilterCounter = this.offerTypeFilterCounter.asObservable();
        this.categoryFilterCounter = new BehaviorSubject_1.BehaviorSubject(0);
        this.currentCategoryFilterCounter = this.categoryFilterCounter.asObservable();
        this.eventsFilterCounter = new BehaviorSubject_1.BehaviorSubject(0);
        this.currentEventsFilterCounter = this.eventsFilterCounter.asObservable();
        this._couponCategories = [];
        this._couponEvents = [];
        this._couponOfferTypes = [];
        this._couponAisleTypes = [];
    }
    /* Add Category Filter */
    CouponFilterService.prototype.addCouponCategory = function (value) {
        var queryString = encodeURIComponent(value);
        var isValid = this.isExist(this._couponCategories, queryString);
        if (isValid.length == 0) {
            var objValue = { 'query': queryString, 'text': value };
            this._couponCategories.push(objValue);
            this.couponCategorySource.next(this._couponCategories);
        }
    };
    /* Add Event Filter */
    CouponFilterService.prototype.addCouponEvent = function (value) {
        var queryString = "";
        queryString = encodeURIComponent(value);
        var isValid = this.isExist(this._couponEvents, queryString);
        if (isValid.length == 0) {
            var objValue = { 'query': queryString, 'text': value };
            this._couponEvents.push(objValue);
            this.couponEventSource.next(this._couponEvents);
        }
    };
    /* Add Offer Type Filter */
    CouponFilterService.prototype.addCouponOfferType = function (value) {
        var queryString = encodeURIComponent(value);
        var isValid = this.isExist(this._couponOfferTypes, queryString);
        if (isValid.length == 0) {
            var objValue = { 'query': queryString, 'text': value };
            this._couponOfferTypes.push(objValue);
            this.couponOfferTypeSource.next(this._couponOfferTypes);
        }
    };
    /* Add Aisle Type Filter */
    CouponFilterService.prototype.addCouponAisleType = function (value) {
        var queryString = encodeURIComponent(value);
        var isValid = this.isExist(this._couponAisleTypes, queryString);
        if (isValid.length == 0) {
            var objValue = { 'query': queryString, 'text': value };
            this._couponAisleTypes.push(objValue);
            this.couponAisleTypeSource.next(this._couponAisleTypes);
        }
    };
    CouponFilterService.prototype.isExist = function (arr, value) {
        return arr.filter(function (objValue) {
            return objValue.query.toLowerCase().indexOf(value.toLowerCase()) > -1;
        });
    };
    /* Set Params for Filters */
    CouponFilterService.prototype.addFilterCategoryParam = function (param) {
        this.filterCategoryParamSource.next(param);
    };
    CouponFilterService.prototype.addFilterEventParam = function (param) {
        this.filterEventParamSource.next(param);
    };
    CouponFilterService.prototype.addFilterOfferTypeParam = function (param) {
        this.filterOfferTypeParamSource.next(param);
    };
    CouponFilterService.prototype.addFilterAisleTypeParam = function (param) {
        this.filterAisleTypeParamSource.next(param);
    };
    /* Count Category Filter Choices */
    CouponFilterService.prototype.countCategoryFilters = function (counter) {
        this.categoryFilterCounter.next(counter);
    };
    /* Count Events Filter Choices */
    CouponFilterService.prototype.countEventsFilters = function (counter) {
        this.eventsFilterCounter.next(counter);
    };
    /* Count Offer Type Filter Choices */
    CouponFilterService.prototype.countOfferTypeFilters = function (counter) {
        this.offerTypeFilterCounter.next(counter);
    };
    /* Filter data pushState() */
    CouponFilterService.prototype.applyFilter = function (message) {
        this.addFilterSource.next(message);
    };
    CouponFilterService.prototype.applyFilterAll = function () {
        this.addAllFilters.next(true);
    };
    CouponFilterService.prototype.clearAllFilters = function () {
        event.stopPropagation();
        window.history.replaceState({}, null, window.location.pathname);
        window.location.reload();
    };
    CouponFilterService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [])
    ], CouponFilterService);
    return CouponFilterService;
}());
exports.CouponFilterService = CouponFilterService;
//# sourceMappingURL=coupon-filter.service.js.map