"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var app_config_service_1 = require("./app.config.service");
var reward_service_1 = require("./../j4u/reward.service");
var rewards_summary_service_1 = require("./../j4u/rewards-summary/rewards-summary.service");
// Window global declaration
function _window() {
    return window;
}
var ClipService = /** @class */ (function () {
    function ClipService(_http, _appConfigService, _rewardService, _rewardSummaryService) {
        this._http = _http;
        this._appConfigService = _appConfigService;
        this._rewardService = _rewardService;
        this._rewardSummaryService = _rewardSummaryService;
    }
    ClipService.prototype.clipCoupon = function (coupon, callback) {
        console.log("clipCoupon Service :", coupon);
        if (_window().AB.COMMON.authorizeJ4U()) {
            console.log(" YES AUTHORIZED ");
            var httpOptions = { headers: new http_1.HttpHeaders(window['AB'].j4uHttpOptions) };
            var reqBody = {};
            if (coupon.deleted) {
                reqBody = {
                    items: [
                        {
                            clipType: 'L',
                            itemId: coupon.offerId,
                            itemType: coupon.offerPgm,
                        },
                    ],
                };
            }
            else {
                reqBody = {
                    items: [
                        {
                            clipType: 'C',
                            itemId: coupon.offerId,
                            itemType: coupon.offerPgm,
                        },
                        {
                            clipType: 'L',
                            itemId: coupon.offerId,
                            itemType: coupon.offerPgm,
                        },
                    ],
                };
            }
            this._http.post(window['AB']['couponClipPath'], reqBody, httpOptions)
                .subscribe(function (response) {
                console.log('clip response', response);
                var allCoupons = JSON.parse(localStorage.getItem('abCoupons'));
                allCoupons.offers[coupon.id].status = 'C';
                localStorage.setItem('abCoupons', JSON.stringify(allCoupons));
                callback();
            }, function (err) { return console.error('clip error', err); });
        }
        else {
            console.log(" NO AUTHORIZED ");
            _window().AB.COMMON.showCreateAccontModalJ4U();
        }
    };
    ClipService.prototype.clipReward = function (reward, callback) {
        var _this = this;
        if (_window().AB.COMMON.authorizeJ4U()) {
            if (window['SWY']['ENFORCEMENT'].isTokenActive()) {
                this.doRedeemReward(reward, callback);
            }
            else if (window['SWY']['ENFORCEMENT'].checkAuthorizedCookie()) {
                this._http.get(window['AB']['userInfoPath']).subscribe(function (data) {
                    window['AB']['userInfo'].updateTokenRefreshProperty();
                    _this.doRedeemReward(reward, callback);
                }, function (error) {
                    reward.isConfirmModalButtonDisabled = false;
                    window['AB']['COMMON'].redirectErrorPage();
                });
            }
        }
        else {
            console.log(" NO AUTHORIZED ");
            reward.isConfirmModalButtonDisabled = false;
            _window().AB.COMMON.showCreateAccontModalJ4U();
        }
    };
    ClipService.prototype.doRedeemReward = function (reward, callback) {
        var _this = this;
        var httpOptions = { headers: new http_1.HttpHeaders(window['AB'].j4uHttpOptions) };
        var rewardUrl = window['AB']['couponClipPath'] + "?storeId=" + window['AB']['userInfo']['j4u']['storeId'];
        var reqBody = {
            items: [
                {
                    clipType: 'C',
                    itemId: reward.groceryRewardId,
                    itemType: reward.offerPgm,
                },
                {
                    clipType: 'L',
                    itemId: reward.groceryRewardId,
                    itemType: reward.offerPgm,
                },
            ],
        };
        this._http.post(rewardUrl, reqBody, httpOptions)
            .subscribe(function (response) {
            if (response['items']) {
                // Got the response with Items
                var items = response["items"];
                // look for the error codes in the response
                if (items[0]['status'] == 1) {
                    // Success
                    _this._updateLocalStorageRewardsInfo(reward);
                    _this._rewardService.updateTimeToRefresh();
                    _this._appConfigService.rewardsRefreshSource.next(true);
                    _this._updateRewardsAnalytics(reward);
                    // Refresh the page after all is success
                    window.location.href = window.location.href.split('justforu')[0] + 'justforu/rewards.html';
                }
                else {
                    _this._handleErrorMessage(reward, items);
                }
            }
            else {
                _this._handleErrorMessage(reward, []);
            }
        }, function (err) {
            console.error('clip error', err);
            var strError = err.status + ": Rewards Clip failed";
            if (err.error && err.error.items && Array.isArray(err.error.items) && err.error.items.length > 0) {
                _this._handleErrorMessage(reward, err.error.items);
            }
            else if (err.message && err.status) {
                strError += " " + err.message + " " + err.status;
                _this._handleErrorMessage(reward, []);
            }
            window['AB']['DATALAYER'].setError(reward.groceryRewardId.toString(), 'rewards clipping', strError);
            window['AB']['DATALAYER'].updateSatelliteTrack('grocery_rewards_error');
        });
    };
    ClipService.prototype._handleErrorMessage = function (reward, items) {
        var errorTitle, errorMessage, strSystemError;
        if (items && items.length > 0) {
            strSystemError = "400: Rewards Clip failed - status is 0";
            if (items[0].errorCd && items[0].errorMsg) {
                strSystemError += " " + items[0].errorCd + " " + items[0].errorMsg;
            }
            if (items[0]['errorCd'] && items[0]['errorCd'] === 'EMJOC8024E') {
                // Show Insufficient Balance message.
                errorTitle = 'Oops';
                errorMessage = 'Your reward balance is being updated, please check back in a few minutes.';
            }
            else {
                // Show Generic Error
                errorTitle = 'Service Problem';
                errorMessage = 'System is currently unavailable, please try again later.';
            }
        }
        else {
            // Show Generic Error
            strSystemError = "400: Rewards Clip failed - items is not defined. ";
            errorTitle = 'Service Problem';
            errorMessage = 'System is currently unavailable, please try again later.';
        }
        // Hide the Modal in case of error.
        var modalID = "#rewards-redemption-confirmation-modal-" + reward.groceryRewardId;
        $(modalID).modal('hide');
        //Show error message
        window['AB']['COMMON'].popupUserErrorMessage(errorTitle, errorMessage, function () {
            // Refresh the page after user clicks the button.
            window.location.href = window.location.href.split('justforu')[0] + 'justforu/rewards.html';
        });
        window['AB']['DATALAYER'].setError(reward.groceryRewardId.toString(), 'rewards clipping', strSystemError);
        window['AB']['DATALAYER'].updateSatelliteTrack('grocery_rewards_error');
    };
    ClipService.prototype._updateRewardsAnalytics = function (reward) {
        window['AB']['DATALAYER'].clipReward(reward);
    };
    // Update the local storage for temporary storing the rewards.
    ClipService.prototype._updateLocalStorageRewardsInfo = function (reward) {
        if (this._appConfigService.isLSCompatible()) {
            var abRewardsSummaryLS = localStorage.abRewardsSummary;
            if (this._rewardSummaryService.checkSummaryTime(abRewardsSummaryLS)) {
                var objRewardsPoints = JSON.parse(abRewardsSummaryLS);
                var rewardsAvailable = objRewardsPoints.rewardsAvailable - reward.rewardsRequired;
                // If the rewardReq is greater then the expRewards
                // replace it with Zero.
                // else (expReward - rewardReq)
                var rewardExpire = (objRewardsPoints.rewardsExpire > reward.rewardsRequired) ?
                    objRewardsPoints.rewardsExpire - reward.rewardsRequired : 0;
                var time = Date.now();
                var abRewardsSummary = { 'rewardsAvailable': rewardsAvailable, 'rewardsExpire': rewardExpire, 'savedTime': time };
                localStorage.abRewardsSummary = JSON.stringify(abRewardsSummary);
            }
            else {
                var rewardsAvailable = reward.rewardsAvailable - reward.rewardsRequired;
                var rewardExpire = (reward.rewardsExpire > reward.rewardsRequired) ? (reward.rewardsExpire - reward.rewardsRequired) : 0;
                var time = Date.now();
                var abRewardsSummary = { 'rewardsAvailable': rewardsAvailable, 'rewardsExpire': rewardExpire, 'savedTime': time };
                localStorage.abRewardsSummary = JSON.stringify(abRewardsSummary);
            }
        }
    };
    ClipService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [http_1.HttpClient, app_config_service_1.AppConfigService, reward_service_1.RewardService, rewards_summary_service_1.RewardsSummaryService])
    ], ClipService);
    return ClipService;
}());
exports.ClipService = ClipService;
//# sourceMappingURL=clip.service.js.map