"use strict";
/**
 * Rewards Grid Service - Get all required data
 *
 * @memberof RewardGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var Observable_1 = require("rxjs/Observable");
require("rxjs/add/observable/of");
var data_model_1 = require("./data.model");
// Data Model
var RewardService = /** @class */ (function () {
    function RewardService(_http) {
        this._http = _http;
    }
    RewardService.prototype.getData = function () {
        var rewardGridOffers = this.get('abRewards');
        var result = Observable_1.Observable.of('');
        if (rewardGridOffers && Array.isArray(rewardGridOffers.offers) && rewardGridOffers.offers.length > 0) {
            var currentTime = new Date();
            currentTime = Date.parse(currentTime);
            if (rewardGridOffers.savedTime == '' || (currentTime - Number(rewardGridOffers.savedTime)) / 1000 / 60 > 30 || window['AB'].userInfo.j4u.storeId != rewardGridOffers.storeId) {
                result = this.getRemoteData();
            }
            else {
                result = Observable_1.Observable.of(rewardGridOffers.offers);
            }
        }
        else {
            result = this.getRemoteData();
        }
        return result;
    };
    RewardService.prototype.getRemoteData = function () {
        var _this = this;
        var dataUrl = window['AB'].rewardPath + "?storeId=" + window['AB'].userInfo.j4u.storeId + '&sortAsc=specialRank';
        var httpOptions = { headers: new http_1.HttpHeaders(window['AB'].j4uHttpOptions) };
        return this._http.get(dataUrl, httpOptions)
            .map(function (response) {
            if (response && response['grOffers']) {
                var savedTime = new Date();
                savedTime = Date.parse(savedTime);
                var savingData = {
                    savedTime: savedTime,
                    offers: response['grOffers'],
                    storeId: window['AB'].userInfo.j4u.storeId
                };
                _this.set('abRewards', savingData);
                return response['grOffers'];
            }
            else {
                return '';
            }
        });
    };
    RewardService.prototype.set = function (key, data) {
        try {
            localStorage.setItem(key, JSON.stringify(data));
        }
        catch (e) {
            console.error('Error saving to localStorage', e);
        }
    };
    RewardService.prototype.get = function (key) {
        try {
            return JSON.parse(localStorage.getItem(key));
        }
        catch (e) {
            console.error('Error getting data from localStorage', e);
            return null;
        }
    };
    // For reward details call + mapping of data
    RewardService.prototype.getOneReward = function (offerId) {
        var httpOptions = { headers: new http_1.HttpHeaders(window['AB'].j4uHttpOptions) };
        return this._http.get(window['AB'].offerDetailPath + "/" + offerId, httpOptions)
            .map(function (data) {
            var reward = new data_model_1.RewardModel;
            if (data != '') {
                var offerPgmLabel = window['SWY'].CONFIGSERVICE.nimbusConfig.couponTypes[data['offerPgm']];
                reward['endDate'] = data['offerEndDate'];
                reward['imagePath'] = window['SWY'].CONFIGSERVICE.nimbusConfig.couponImageBaseUrl + data['imageId'];
                reward['offerType'] = window['SWY'].CONFIGSERVICE.nimbusConfig.offerTypes[data['usageType']];
                reward['generalDisclaimer'] = (data['offerDetail']['disclaimer']) ? data['offerDetail']['disclaimer'] : "";
                reward['offerPgm'] = data['offerPgm'];
                reward['offerSubPgm'] = data['offerSubPgm'];
                reward['offerPrice'] = data['offerDetail'].savingsValue;
                reward['title'] = data['offerDetail'].titleDsc1 + ((data['offerDetail'].titleDsc2) ? (" " + data['offerDetail'].titleDsc2) : " ");
                reward['description'] = data['offerDetail'].prodDsc1;
            }
            return reward;
        });
    };
    RewardService.prototype.updateTimeToRefresh = function () {
        var rewardGridOffers = this.get('abRewards');
        if (rewardGridOffers) {
            rewardGridOffers.savedTime = '';
            this.set('abRewards', rewardGridOffers);
        }
    };
    RewardService.prototype.dateConversion = function (dateServer) {
        var dateStr = dateServer;
        var regex = /\d+/;
        var mills = regex.exec(dateStr);
        var result = '';
        if (Array.isArray(mills)) {
            var d = new Date(parseInt(mills[0]));
            d.setUTCMilliseconds(mills.index);
            result = d.toLocaleDateString("en-US");
        }
        return result;
    };
    RewardService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [http_1.HttpClient])
    ], RewardService);
    return RewardService;
}());
exports.RewardService = RewardService;
//# sourceMappingURL=reward.service.js.map