"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/**
 * Rewards Summary Service - Get all required data
 *
 * @memberof RewardsSummary
 */
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var BehaviorSubject_1 = require("rxjs/BehaviorSubject");
var app_config_service_1 = require("./app.config.service");
var RewardsSummaryService = /** @class */ (function () {
    function RewardsSummaryService(_http, _appConfigService, zone) {
        this._http = _http;
        this._appConfigService = _appConfigService;
        this.summaryTimeValue = window['AB']['rewardSummaryTime']; //this is the time for summary to take from local storage in miliseconds
        this.AB = window['AB'];
        this.rewardsPointSource = new BehaviorSubject_1.BehaviorSubject('');
        this.currentRewardsPoints = this.rewardsPointSource.asObservable();
        if (window['AB'].COMMON.authorize()) {
            window['AB'].ucaRewardsTrigger = false;
            //this.getRemoteData();
        }
        else {
            this.rewardsPointSource.next({});
        }
        window['rewardSummaryServiceRef'] = {
            zone: zone,
            service: this
        };
    }
    RewardsSummaryService.prototype.getData = function () {
        return this.currentRewardsPoints;
    };
    RewardsSummaryService.prototype.setData = function (rewardsPointsData) {
        this.rewardsPointSource.next(rewardsPointsData);
    };
    RewardsSummaryService.prototype.getRemoteData = function () {
        var _this = this;
        var rewardsSumaryUrl = this.AB.COMMON.ucaAPIPathWithCustomerId(this.AB.rewardsHeaderSummaryPath);
        var httpOptions = { headers: new http_1.HttpHeaders(this.AB.preUcaHttpOptions) };
        this._http.get(rewardsSumaryUrl, httpOptions).subscribe(function (data) {
            _this.rewardsPointSource.next(data);
            if (typeof window['AB'].UCAREWARDS == 'object' && typeof window['AB'].UCAREWARDS.renderRewardPoints == 'function') {
                window['AB'].UCAREWARDS.renderRewardPoints(data);
            }
        }, function (error) {
            _this.rewardsPointSource.next({});
            if (typeof window['AB'].UCAREWARDS == 'object' && typeof window['AB'].UCAREWARDS.renderRewardsError == 'function') {
                window['AB'].UCAREWARDS.renderRewardsError(error);
            }
        });
    };
    RewardsSummaryService.prototype.checkSummaryTime = function (abRewardsSummaryLS) {
        return abRewardsSummaryLS && ((Date.now() - JSON.parse(abRewardsSummaryLS).savedTime) <= this.summaryTimeValue); //check for summary localStorage time and now difference to be maximum the declared number
    };
    RewardsSummaryService.prototype.useOrDeleteSummary = function () {
        var result = false;
        if (this._appConfigService.isLSCompatible()) {
            var abRewardsSummaryLS = localStorage.abRewardsSummary;
            if (this.checkSummaryTime(abRewardsSummaryLS)) {
                result = true;
            }
            else if (abRewardsSummaryLS) {
                localStorage.removeItem('abRewardsSummary');
                result = false;
            }
        }
        return result;
    };
    RewardsSummaryService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [http_1.HttpClient, app_config_service_1.AppConfigService, core_1.NgZone])
    ], RewardsSummaryService);
    return RewardsSummaryService;
}());
exports.RewardsSummaryService = RewardsSummaryService;
//# sourceMappingURL=rewards-summary.service.js.map