/**
 * Rewards Grid Service - Get all required data
 *
 * @memberof RewardGrid
 */

import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/of';
import { RewardModel } from './data.model';

// Data Model

@Injectable()
export class RewardService {

    public constructor(private _http: HttpClient) {
    }

    public getData(): Observable<any> {
        const rewardGridOffers = this.get('abRewards');
        let result = Observable.of('');

        if (rewardGridOffers && Array.isArray(rewardGridOffers.offers) && rewardGridOffers.offers.length > 0) {
            let currentTime: any = new Date();
            currentTime = Date.parse(currentTime);
            if (rewardGridOffers.savedTime == '' || (currentTime - Number(rewardGridOffers.savedTime)) / 1000 / 60 > 30 || window['AB'].userInfo.j4u.storeId != rewardGridOffers.storeId) {
                result = this.getRemoteData();
            } else {
                result = Observable.of(rewardGridOffers.offers);
            }
        } else {
            result = this.getRemoteData();
        }

        return result;
    }

    public getRemoteData(): Observable<any> {
        var dataUrl = window['AB'].rewardPath + "?storeId=" + window['AB'].userInfo.j4u.storeId + '&sortAsc=specialRank';
        let httpOptions = { headers: new HttpHeaders(window['AB'].j4uHttpOptions) };

        return this._http.get(dataUrl, httpOptions)
            .map(response => {
                if (response && response['grOffers']) {
                    let savedTime: any = new Date();
                    savedTime = Date.parse(savedTime);
                    let savingData = {
                        savedTime,
                        offers: response['grOffers'],
                        storeId: window['AB'].userInfo.j4u.storeId
                    };
                    this.set('abRewards', savingData);
                    return response['grOffers'];
                } else {
                    return '';
                }
            });
    }

    private set(key: string, data: any): void {
        try {
            localStorage.setItem(key, JSON.stringify(data));
        } catch (e) {
            console.error('Error saving to localStorage', e);
        }
    }

    private get(key: string) {
        try {
            return JSON.parse(localStorage.getItem(key));
        } catch (e) {
            console.error('Error getting data from localStorage', e);
            return null;
        }
    }

    // For reward details call + mapping of data
    public getOneReward(offerId: any): Observable<RewardModel> {
        let httpOptions = { headers: new HttpHeaders(window['AB'].j4uHttpOptions) };
        return this._http.get(window['AB'].offerDetailPath + "/" + offerId, httpOptions)
            .map(data => {
                let reward : RewardModel = new RewardModel;
                if (data != '') {
                    let offerPgmLabel = window['SWY'].CONFIGSERVICE.nimbusConfig.couponTypes[data['offerPgm']];
                    reward['endDate'] = data['offerEndDate'];
                    reward['imagePath'] = window['SWY'].CONFIGSERVICE.nimbusConfig.couponImageBaseUrl + data['imageId'];
                    reward['offerType'] = window['SWY'].CONFIGSERVICE.nimbusConfig.offerTypes[data['usageType']];
                    reward['generalDisclaimer'] = (data['offerDetail']['disclaimer']) ? data['offerDetail']['disclaimer'] : "";
                    reward['offerPgm'] = data['offerPgm'];
                    reward['offerSubPgm'] = data['offerSubPgm'];
                    reward['offerPrice'] = data['offerDetail'].savingsValue;
                    reward['title'] = data['offerDetail'].titleDsc1 + ((data['offerDetail'].titleDsc2) ? (" " + data['offerDetail'].titleDsc2) : " ");
                    reward['description'] = data['offerDetail'].prodDsc1;
                }
                return reward;
            });
    }

    public updateTimeToRefresh() {
        const rewardGridOffers = this.get('abRewards');

        if(rewardGridOffers) {
            rewardGridOffers.savedTime = '';
            this.set('abRewards', rewardGridOffers);
        }
    }

    public dateConversion(dateServer: string): string {
        let dateStr = dateServer;
        let regex = /\d+/;
        let mills = regex.exec(dateStr);
        let result = '';
        if(Array.isArray(mills)) {
            let d = new Date(parseInt(mills[0]));
            d.setUTCMilliseconds(mills.index);
            result = d.toLocaleDateString("en-US");
        }

        return result;
    }


}
