/**
 * Rewards Summary Service - Get all required data
 *
 * @memberof RewardsSummary
 */
import {Injectable,NgZone} from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {Observable} from 'rxjs/Observable';
import { BehaviorSubject }    from 'rxjs/BehaviorSubject';
import { AppConfigService } from './app.config.service';

@Injectable()
export class RewardsSummaryService {
    public summaryTimeValue = window['AB']['rewardSummaryTime']; //this is the time for summary to take from local storage in miliseconds
    public AB = window['AB'];
    private rewardsPointSource = new BehaviorSubject<any>('');
    public currentRewardsPoints = this.rewardsPointSource.asObservable();

    public constructor(private _http: HttpClient, private _appConfigService: AppConfigService, zone: NgZone) {
        if(window['AB'].COMMON.authorize()) {
            window['AB'].ucaRewardsTrigger = false;
            //this.getRemoteData();
        }else {
            this.rewardsPointSource.next({});
        }
        window[ 'rewardSummaryServiceRef' ] = {
            zone: zone,
            service: this
        };
    }

    public getData(): Observable<any> {
        return this.currentRewardsPoints;
    }

    public setData(rewardsPointsData) {
        this.rewardsPointSource.next(rewardsPointsData);
    }

    public getRemoteData() {
        let rewardsSumaryUrl = this.AB.COMMON.ucaAPIPathWithCustomerId(this.AB.rewardsHeaderSummaryPath);
        let httpOptions = {headers: new HttpHeaders(this.AB.preUcaHttpOptions)};
        this._http.get(rewardsSumaryUrl, httpOptions).subscribe((data) => {
            this.rewardsPointSource.next(data);
            if(typeof window['AB'].UCAREWARDS == 'object' && typeof window['AB'].UCAREWARDS.renderRewardPoints == 'function') {
                window['AB'].UCAREWARDS.renderRewardPoints(data);
            }
        }, error => {
            this.rewardsPointSource.next({});
            if(typeof window['AB'].UCAREWARDS == 'object' && typeof window['AB'].UCAREWARDS.renderRewardsError == 'function') {
                window['AB'].UCAREWARDS.renderRewardsError(error);
            }
        });
    }


    public checkSummaryTime(abRewardsSummaryLS){
        return abRewardsSummaryLS && ( (Date.now() - JSON.parse(abRewardsSummaryLS).savedTime) <= this.summaryTimeValue);  //check for summary localStorage time and now difference to be maximum the declared number
    }

    public useOrDeleteSummary(){
        let result = false;
        if(this._appConfigService.isLSCompatible()){
            let abRewardsSummaryLS = localStorage.abRewardsSummary;
            if(this.checkSummaryTime(abRewardsSummaryLS)){
                result = true;
            }else if(abRewardsSummaryLS){
                localStorage.removeItem('abRewardsSummary');
                result = false;
            }
        }
        return result;
    }
}
